.. ==================================
   BuildBot Documentation - |version|
   ==================================

This is the BuildBot documentation for Buildbot version |version|.

If you are evaluating Buildbot and would like to get started quickly, start
with the :doc:`Tutorial <tutorial/index>`.  Regular users of Buildbot should
consult the :doc:`Manual <manual/index>`, and those wishing to modify Buildbot
directly will want to be familiar with the :doc:`Developer's Documentation
<developer/index>`.

Table Of Contents
-----------------

.. toctree::
   :maxdepth: 2

   tutorial/index
   manual/index
   developer/index
   release-notes

Indices and Tables
==================

* :ref:`genindex`
* :bb:index:`cfg`
* :bb:index:`sched`
* :bb:index:`chsrc`
* :bb:index:`step`
* :bb:index:`status`
* :bb:index:`cmdline`
* :ref:`modindex`
* :ref:`search`

Copyright
=========

Copyright Buildbot Team Members

Copying and distribution of this file, with or without modification, are
permitted in any medium without royalty provided the copyright notice and this
notice are preserved.
